package net.sf.doolin.util;

import net.sf.sido.PropertyAccessor;

import org.apache.commons.lang.StringUtils;

public abstract class AbstractPropertySet implements PropertyAccessor {

	protected abstract PropertyAccessor createPropertySet(PropertyAccessor parentSet,
			String nameInParent);

	protected abstract Object getSimple(String name);

	@Override
	public Object getValue(String propertyPath) {
		// Checks the arguments
		if (StringUtils.isBlank(propertyPath)) {
			throw new IllegalArgumentException("propertyPath must not be blank");
		}
		// Nested property?
		String prefix = StringUtils.substringBefore(propertyPath, SEPARATOR);
		String leftOver = StringUtils.substringAfter(propertyPath, SEPARATOR);
		if (StringUtils.isNotBlank(leftOver)) {
			// Gets the prefix property
			Object prefixProperty = getSimple(prefix);
			if (prefixProperty == null) {
				// None found
				return null;
			} else {
				// Gets the property recursively
				return Utils.getProperty(prefixProperty, leftOver);
			}
		}
		// Simple property
		else {
			return getSimple(prefix);
		}
	}

	protected abstract void setSimple(String name, Object value);

	@Override
	public PropertyAccessor setValue(String propertyPath, Object value) {
		// Checks the arguments
		if (StringUtils.isBlank(propertyPath)) {
			throw new IllegalArgumentException("propertyPath must not be blank");
		}
		// Nested property?
		String prefix = StringUtils.substringBefore(propertyPath, SEPARATOR);
		String leftOver = StringUtils.substringAfter(propertyPath, SEPARATOR);
		if (StringUtils.isNotBlank(leftOver)) {
			// Gets the prefix property
			Object prefixProperty = getSimple(prefix);
			if (prefixProperty == null) {
				// Creates the prefix property as set
				PropertyAccessor prefixPropertySet = createPropertySet(this, prefix);
				// Registers it
				setSimple(prefix, prefixPropertySet);
				// Goes on
				Utils.setProperty(prefixPropertySet, leftOver, value);
			} else {
				// Sets the property recursively
				Utils.setProperty(prefixProperty, leftOver, value);
			}
		}
		// Simple property
		else {
			setSimple(prefix, value);
		}
		// OK
		return this;
	}

}
