package net.sf.doolin.util;

import java.util.Locale;

import org.apache.commons.lang.StringUtils;

/**
 * Defines how a Locale must be used when looking for resources
 * 
 * @author Damien Coraboeuf
 */
public enum ELocaleMode {
	/**
	 * Defines the full locale, including language and country.
	 */
	LANGUAGE_COUNTRY {
		@Override
		public Locale getLocale(Locale locale) {
			return locale;
		}
	},
	/**
	 * Defines the language only.
	 */
	LANGUAGE {
		@Override
		public Locale getLocale(Locale locale) {
			if (locale == null) {
				return null;
			} else if (StringUtils.isNotBlank(locale.getLanguage())) {
				return new Locale(locale.getLanguage());
			} else {
				return null;
			}
		}
	},
	/**
	 * Independant from the locale.
	 */
	NONE {
		@Override
		public Locale getLocale(Locale locale) {
			return null;
		}
	};

	/**
	 * Converts a locale
	 * 
	 * @param locale
	 *            Locale to convert.
	 * @return <code>null</code> if the conversion cannot be done.
	 */
	public abstract Locale getLocale(Locale locale);
}
