package net.sf.doolin.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Adapter where the update of the subject is deactivated.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <S>
 *            Subject type
 * @param <T>
 *            Target type
 */
public abstract class ReadOnlyAdapter<S, T> implements Adapter<S, T> {

	private static final Logger log = LoggerFactory.getLogger(ReadOnlyAdapter.class);

	/**
	 * Logs a warning and returns null.
	 */
	@Override
	public final S convertTargetToSubject(T targetValue) {
		log.warn(String.format("Attempt to update a read-only adapter with %s",
				targetValue));
		return null;
	}

}
