/**
 * 
 */
package net.sf.doolin.util.expression;

import java.util.LinkedList;
import java.util.List;

/**
 * List of {@link Token}s.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class TokenList extends AbstractToken {

	private LinkedList<Token> tokenList = new LinkedList<Token>();

	/**
	 * Constructor.
	 */
	public TokenList(TokenType tokenType) {
		super(tokenType);
	}

	@Override
	public void add(Token add) {
		this.tokenList.add(add);
	}

	@Override
	public Token addText(char c) {
		if (this.tokenList.isEmpty()) {
			TextToken token = new TextToken();
			token.addText(c);
			this.tokenList.add(token);
			return token;
		} else {
			Token token = this.tokenList.getLast();
			if (token.isClosed() || token.getType() != TokenType.TEXT) {
				token = new TextToken();
				token.addText(c);
				this.tokenList.add(token);
				return token;
			} else {
				return token.addText(c);
			}
		}
	}

	protected List<Token> getTokens() {
		return this.tokenList;
	}

	@Override
	public boolean isVariable() {
		for (Token token : this.tokenList) {
			if (token.isVariable()) {
				return true;
			}
		}
		return false;
	}

	@Override
	public boolean supportAdd() {
		return true;
	}

	@Override
	public void visitTokensWith(TokenVisitor visitor) {
		if (!this.tokenList.isEmpty()) {
			for (Token token : this.tokenList) {
				token.visitTokensWith(visitor);
			}
		}
	}

}